searchData={"items":[{"type":"module","title":"Kase","doc":"A module for converting strings between different casing styles.","ref":"Kase.html"},{"type":"function","title":"Kase.convert/2","doc":"Converts a given `string` to the specified `target_case`.","ref":"Kase.html#convert/2"},{"type":"function","title":"Examples - Kase.convert/2","doc":"iex> Kase.convert(\"this-variable-name\", :camel_case)\n    \"thisVariableName\"\n\n    iex> Kase.convert(\"ThisIsPascalCase\", :snake_case)\n    \"this_is_pascal_case\"\n\n    map_input = %{\"first_key\" => \"value\", \"second_key\" => \"value\"}\n    iex> Kase.convert(map_input, :camel_case)\n    %{\"firstKey\" => \"value\", \"secondKey\" => \"value\"}","ref":"Kase.html#convert/2-examples"},{"type":"function","title":"Kase.convert/3","doc":"","ref":"Kase.html#convert/3"},{"type":"module","title":"Kase.Conversor","doc":"A module for converting strings between different casing styles.","ref":"Kase.Conversor.html"},{"type":"function","title":"Kase.Conversor.convert/2","doc":"Converts a given `string` to the specified `target_case`.","ref":"Kase.Conversor.html#convert/2"},{"type":"function","title":"Examples - Kase.Conversor.convert/2","doc":"iex> Kase.convert(\"THIS-IS-COBOL-CASE\", :humanized_case)\n    \"This is cobol case\"\n\n    iex> Kase.convert(\"this-variable-name\", :camel_case)\n    \"thisVariableName\"\n\n    iex> Kase.convert(\"ThisIsPascalCase\", :snake_case)\n    \"this_is_pascal_case\"\n\n    iex> Kase.convert(\"snake_case_var\", :kebab_case)\n    \"snake-case-var\"\n\n    iex> Kase.convert(\"PascalCaseVar\", :upper_case_snake_case)\n    \"PASCAL_CASE_VAR\"\n\n    iex> Kase.convert(\"this-is-an-example\", :train_case)\n    \"This-Is-An-Example\"\n\n    iex> Kase.convert(\"this_is_cobol_case\", :cobol_case)\n    \"THIS-IS-COBOL-CASE\"\n\n    iex> Kase.convert(\"exampleForDotCase\", :dot_case)\n    \"example.for.dot.case\"","ref":"Kase.Conversor.html#convert/2-examples"},{"type":"function","title":"Supported target cases - Kase.Conversor.convert/2","doc":"- `:camel_case`\n- `:cobol_case`\n- `:dot_case`\n- `:flat_case`\n- `:humanized_case`\n- `:kebab_case`\n- `:pascal_case`\n- `:snake_case`\n- `:train_case`\n- `:upper_case_snake_case`","ref":"Kase.Conversor.html#convert/2-supported-target-cases"},{"type":"function","title":"Kase.Conversor.from_dot_case_to_flat_case/1","doc":"","ref":"Kase.Conversor.html#from_dot_case_to_flat_case/1"},{"type":"type","title":"Kase.Conversor.target_case/0","doc":"The target case to convert the string to.","ref":"Kase.Conversor.html#t:target_case/0"},{"type":"extras","title":"Käse","doc":"# Käse\n\n[![Kase Package](https://img.shields.io/hexpm/v/kase.svg)](https://hex.pm/packages/kase/0.3.0)\n\nKäse is an Elixir library for converting strings between various casing styles, including camelCase, snake_case, kebab-case, PascalCase, and more. Whether you're working with data from different sources or simply want to format strings in a specific way, Käse provides a straightforward API to handle these conversions.","ref":"readme.html"},{"type":"extras","title":"Installation - Käse","doc":"To use Käse in your Elixir project, add it to your `mix.exs` file:\n\n```elixir\ndefp deps do\n  [\n    {:kase, \"~> 0.3.0\"}\n  ]\nend\n```\n\nThen run the following command to install the dependency:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Käse","doc":"You can convert strings between different casing styles using the `Kase.convert/2` function. Here are some examples:","ref":"readme.html#usage"},{"type":"extras","title":"Convert to camelCase - Käse","doc":"```elixir\nKase.convert(\"this_is_an_example\", :camel_case)\n# => \"thisIsAnExample\"\n\nKase.convert(\"ThisIsPascalCase\", :camel_case)\n# => \"thisIsPascalCase\"\n```","ref":"readme.html#convert-to-camelcase"},{"type":"extras","title":"Convert to snake_case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :snake_case)\n# => \"this_is_an_example\"\n\nKase.convert(\"ThisIsPascalCase\", :snake_case)\n# => \"this_is_pascal_case\"\n```","ref":"readme.html#convert-to-snake_case"},{"type":"extras","title":"Convert to kebab-case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :kebab_case)\n# => \"this-is-an-example\"\n\nKase.convert(\"ThisIsPascalCase\", :kebab_case)\n# => \"this-is-pascal-case\"\n```","ref":"readme.html#convert-to-kebab-case"},{"type":"extras","title":"Convert to PascalCase - Käse","doc":"```elixir\nKase.convert(\"this_is_an_example\", :pascal_case)\n# => \"ThisIsAnExample\"\n\nKase.convert(\"this-is-an-example\", :pascal_case)\n# => \"ThisIsAnExample\"\n```","ref":"readme.html#convert-to-pascalcase"},{"type":"extras","title":"Convert to upper_case_snake_case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :upper_case_snake_case)\n# => \"THIS_IS_AN_EXAMPLE\"\n```","ref":"readme.html#convert-to-upper_case_snake_case"},{"type":"extras","title":"Convert to train-case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :train_case)\n# => \"This-Is-An-Example\"\n```","ref":"readme.html#convert-to-train-case"},{"type":"extras","title":"Convert to dot.case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :dot_case)\n# => \"this.is.an.example\"\n```","ref":"readme.html#convert-to-dot-case"},{"type":"extras","title":"Convert to cobol-case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :cobol_case)\n# => \"THIS-IS-AN-EXAMPLE\"\n```","ref":"readme.html#convert-to-cobol-case"},{"type":"extras","title":"Convert to humanized case - Käse","doc":"```elixir\nKase.convert(\"this_is_an_example\", :humanized_case)\n# => \"This is an example\"\n```","ref":"readme.html#convert-to-humanized-case"},{"type":"extras","title":"Convert Map Keys - Käse","doc":"You can also convert the keys of a map to a desired casing style using Kase.convert/3. This function accepts an optional :to_atoms option to convert the keys into atoms if desired.\n\n\n```elixir\noriginal_map = %{first_name: \"John\", last_name: \"Doe\"}\nKase.convert(original_map, :kebab_case)\n# => %{\"first-name\" => \"John\", \"last-name\" => \"Doe\"}\n```\n\n#### Convert with keys as atoms\n```elixir\nKase.convert(original_map, :kebab_case, to_atoms: true)\n# => %{:first_name => \"John\", :last_name => \"Doe\"}\n```","ref":"readme.html#convert-map-keys"},{"type":"extras","title":"Contributing - Käse","doc":"Contributions are welcome! If you have suggestions for improvements or find bugs, please open an issue or submit a pull request.\n\n1. Fork the project\n2. Create your feature branch: `git checkout -b feature/my-new-feature`\n3. Commit your changes: `git commit -m 'Add some feature'`\n4. Push to the branch: `git push origin feature/my-new-feature`\n5. Open a pull request","ref":"readme.html#contributing"},{"type":"extras","title":"License - Käse","doc":"Käse is released under the MIT License. See the [LICENSE](LICENSE) file for more information.","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgments - Käse","doc":"Thank you for using Käse! We hope it helps make your string handling in Elixir easier and more enjoyable.","ref":"readme.html#acknowledgments"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) [2024] [vicentedpsantos]\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\n1. The above copyright notice and this permission notice shall be included in\n   all copies or substantial portions of the Software.\n\n2. THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\n   SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}